# [Bad Apple!!](https://www.youtube.com/watch?v=FtutLA63Cp8&list=RDFtutLA63Cp8&start_radio=1) Terminal

Essentially a Sunday project fueled by my Touhou love and Diwali holiday snacks; a terminal-based rendition of the classic **Bad Apple!** shadow video from the *Touhou Project*. This plays a video on the CLI as ASCII art with synced audio!

## Installation
1. Clone this repository:
   
```bash
git clone https://github.com/AbhinavMangalore16/badapple-terminal.git
cd badapple-terminal
``` 

2. Install dependencies:
```bash 
pip install -r requirements.txt
```

3. Run the script:
```bash
python badapple_terminal/player.py
```
### Python Package (coming soon!)


## Credits and Acknowledgements

- Original Animation: [Alstroemeria Records](https://alst.net/) (Bad Apple!! MV)
- Source/Game Video: [Touhou Project (ZUN)](https://en.touhouwiki.net/wiki/ZUN)
- Video Courtesy: https://www.youtube.com/watch?v=FtutLA63Cp8&list=RDFtutLA63Cp8&start_radio=1
- Conversion ASCII logic (for refined grainy rendering): https://github.com/kiteco/python-youtube-code/blob/master/ascii/ascii_convert.py
- 
## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.